# Personal grimoire

[![jeanCarloMachado](https://circleci.com/gh/jeanCarloMachado/personal-grimoire.svg?style=svg&circle-token=2749f775ef91e84cb5d6150d1cdf0dcbcdbadf05)](https://app.circleci.com/pipelines/github/jeanCarloMachado/personal-grimoire)


Personal python scripts served as a library for reuse
